@@ -104,7 +104,7 @@ class ValidFormatJob:
             writer = pd.ExcelWriter('test_out.xlsx', engine='xlsxwriter')
             to_excel_chunk = delayed(_write_excel)
 
-            dfs = df.to_delayed()
+            dfs = df.repartition(partition_size="10MB").to_delayed()
 
             def name_function(i: int):
                 return f"part_{i}.xlsx"
@@ -178,8 +178,11 @@ class ValidFormatJob:
         if num_workers:
             max_partition_size = cluster_spec.max_partition_size()
             even_partition_size = size / num_workers 
-            if even_partition_size > max_partition_size:
-                final = InvalidJob(f"Partitions too large for workers: (size, max) = ({even_partition_size}, {max_partition_size}).  Add more workers or increase worker memory.")
+            if max_partition_size:
+                if even_partition_size > max_partition_size:
+                    final = InvalidJob(f"Partitions too large for workers: (size, max) = ({even_partition_size}, {max_partition_size}).  Add more workers or increase worker memory.")
+                else:
+                    final = df.repartition(partition_size=even_partition_size).repartition(npartitions=num_workers)
             else:
                 final = df.repartition(partition_size=even_partition_size).repartition(npartitions=num_workers)
         else:
@@ -192,7 +195,8 @@ class ValidFormatJob:
         
         if isinstance(df, DataFrame):
             def write_partitioned(df: PDataFrame, partition_columns: List[str]):
-                ddf = dd.from_pandas(df, npartitions=cluster_spec.num_workers() or self.partitions)
+                # TODO:  Fix default value
+                ddf = dd.from_pandas(df, npartitions=cluster_spec.num_workers() or self.partitions or 10)
                 labels = {}
 
                 for p in partition_columns:
@@ -212,6 +216,7 @@ class ValidFormatJob:
                     df = df[self.filter_columns]
                     df = self.repartition(df, cluster_spec, self.partitions)
 
+            final: Union[ExecutedJob, InvalidJob]
             if len(self.partition_columns) > 0:
                 check = self.check_columns(df, self.partition_columns)
                 if isinstance(check, InvalidJob):
